@@ -17,6 +17,7 @@ type Config struct {
 	ConfigFile  string
 	AppConfig   *models.AppConfig   `toml:"application"`
 	Connections []models.Connection `toml:"database"`
+	Keymaps     models.KeymapConfig `toml:"keymap"`
 }
 
 func defaultConfig() *Config {
@@ -26,6 +27,7 @@ func defaultConfig() *Config {
 			SidebarOverlay:               false,
 			MaxQueryHistoryPerConnection: 100,
 			TreeWidth:                    30,
+			JSONViewerWordWrap:           false,
 		},
 	}
 }
@@ -72,6 +74,10 @@ func LoadConfig(configFile string) error {
 		App.config.Connections[i].URL = parseConfigURL(&conn)
 	}
 
+	if err := ApplyKeymapConfig(App.config.Keymaps); err != nil {
+		return err
+	}
+
 	return nil
 }
 
