@@ -12,6 +12,7 @@ type AppConfig struct {
 	SidebarOverlay               bool
 	MaxQueryHistoryPerConnection int
 	TreeWidth                    int
+	JSONViewerWordWrap           bool
 }
 
 type Connection struct {
@@ -38,10 +39,13 @@ type Connection struct {
 	Commands []*Command
 }
 
+type KeymapConfig map[string]map[string]string
+
 type Command struct {
 	Command      string
 	WaitForPort  string
 	SaveOutputTo string
+	Timeout      int // Timeout in seconds for command to start (default: 5)
 }
 
 type StateChange struct {
